package MT::Plugin::RebuildAt1stView;
use strict;
use MT;
use MT::Plugin;
use File::Spec;

our $VERSION = '0.3';
our $SCHEMA_VERSION = '0.2';

use base qw( MT::Plugin );

my $plugin = MT::Plugin::RebuildAt1stView->new( {
    id   => 'RebuildAt1stView',
    key  => 'rebuild-at-1st-view',
    name => 'RebuildAt1stView',
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    version => $VERSION,
    schema_version => $SCHEMA_VERSION,
    l10n_class => 'RebuildAt1stView::L10N',
} );

MT->add_plugin( $plugin );

sub init_registry {
    my $plugin = shift;
    $plugin->registry( {
        object_types => {
            'template' => {
                'rebuild_at' => 'boolean',
            },
        },
        callbacks => {
            'build_file_filter'
                => \&_build_file_filter,
            'MT::App::CMS::template_param.edit_template'
                => \&_edit_template_param,
        },
        tags => {
            function => {
                'PluginPath' => \&_hdlr_plugin_path,
            },
        },
   } );
}

sub _hdlr_plugin_path {
    my ( $ctx, $args, $cond ) = @_;
    my $component = $args->{ component };
    my $folder = $args->{ folder };
    my @option = split( /,/, $folder );
    if ( $component ) {
        my $component = MT->component( $component );
        if ( defined $component ) {
            my $path;
            if ( @option ) {
                $path = File::Spec->catdir( $component->path, @option );
            } else {
                $path = $component->path;
            }
            if ( $^O eq 'MSWin32' ) { $path .= '\\' } else { $path .= '/' };
            return $path;
        }
    }
    return '';
}

sub _build_file_filter {
    my ( $eh, %args ) = @_;
    my $template = $args{ template };
    if (! $template->rebuild_at ) {
        return 1;
    }
    my $file = $args{ file };
    if ( -e $file ) {
        unlink $file;
    }
    return 0;
}

sub _edit_template_param {
    my ( $cb, $app, $param, $tmpl ) = @_;
    my $pointer_node = $tmpl->getElementById( 'linked_file' );
    return unless $pointer_node;
    my $tg = $param->{ template_group };
    if ( ( $tg ne 'index' ) && ( $tg ne 'archive' ) ) {
        return;
    }
    my $blog = $app->blog;
    return unless $blog;
    my $node = $tmpl->createElement( 'app:setting', {
        label => $plugin->translate( 'RebuildAt1stView' ),
        id => 'rebuild_at',
        show_label => 0,
        label_class => 'top-level',
    } );
    my $label = $plugin->translate( 'Rebuild this template at 1st view' );
    my $inner = <<MTML;
    <label><input type="checkbox" name="rebuild_at" id="rebuild_at" value="1" <mt:if name="rebuild_at">checked="checked"</mt:if> /> $label</label>
    <input type="hidden" name="rebuild_at" value="0" />
MTML
    $node->innerHTML( $inner );
    $tmpl->insertAfter( $node, $pointer_node );
    if ( my $id = $app->param( 'id' ) ) {
        require MT::Template;
        my $tmplate = MT::Template->load( $id );
        return unless $tmplate;
        my $site_url = $blog->site_url || '';
        $site_url .= '/' if $site_url !~ m!/$!;
        my $url = $site_url . $tmplate->outfile;
        $param->{ published_url } = $url;
    }
}

1;